"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getUnitLabel = exports.representFromBaseUnit = exports.representUnit = exports.representKindAsUnit = exports.unitToKind = exports.kindToUnit = exports.convert = exports.defaultUnits = void 0;

var _jsQuantities = _interopRequireDefault(require("js-quantities"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var defaultUnits = {
  // kind: ['metric', 'imperial', 'option #3', 'option #4', ...]
  length: [{
    name: 'Meters',
    abbv: 'm'
  }, {
    name: 'Feets',
    abbv: 'ft'
  }],
  area: [{
    name: 'Square meters',
    abbv: 'm2',
    label: 'm&sup2;'
  }, {
    name: 'Square feets',
    abbv: 'ft2',
    label: 'ft&sup2;'
  }],
  volume: [{
    name: 'Liters',
    abbv: 'l'
  }, {
    name: 'Fluid-ounces',
    abbv: 'floz'
  }],
  temperature: [{
    name: 'Celsius',
    abbv: 'tempC',
    label: '&deg;C'
  }, {
    name: 'Fahrenheit',
    abbv: 'tempF',
    label: '&deg;F'
  }],
  pressure: [{
    name: 'Pascal',
    abbv: 'MPa'
  }, {
    name: 'psi',
    abbv: 'psi'
  }, {
    name: 'Bars',
    abbv: 'bar'
  }]
};
/**
 * Convert given value(s) from one unit to another.
 * @func
 * @static
 * @param {Number|Array<Number>} values Value(s) to convert.
 * @param {String} from Unit to convert from.
 * @param {String} to Unit to convert into.
 */

exports.defaultUnits = defaultUnits;

var convert = function convert(values, from, to) {
  var converter = _jsQuantities["default"].swiftConverter(from, to);

  return converter(values);
};
/**
 * Returns the SI unit for a given kind.
 * @func
 * @static
 * @param {String} kind The kind to evaluate.
 * @returns {String|undefined} Unit string or undefined if failed.
 */


exports.convert = convert;

var kindToUnit = function kindToUnit(kind) {
  try {
    return (0, _jsQuantities["default"])(1, _jsQuantities["default"].getUnits(kind)[0]).toBase().units();
  } catch (_unused) {
    /* */
  }

  return undefined;
};
/**
 * Get the kind from a given unit.
 * @func
 * @static
 * @param {String} unit Unit to evaluate.
 * @returns {String|undefined} Name of kind or undefined if failed.
 */


exports.kindToUnit = kindToUnit;

var unitToKind = function unitToKind(unit) {
  try {
    return (0, _jsQuantities["default"])(1, unit).kind();
  } catch (_unused2) {
    /* */
  }

  return undefined;
};

exports.unitToKind = unitToKind;

var representKindAsUnit = function representKindAsUnit(kind, units) {
  var _units$kinds = units.kinds,
      kinds = _units$kinds === void 0 ? {} : _units$kinds,
      _units$systems = units.systems,
      systems = _units$systems === void 0 ? {} : _units$systems,
      _units$isMetric = units.isMetric,
      isMetric = _units$isMetric === void 0 ? true : _units$isMetric;
  if (kind in kinds) return kinds[kind];
  if (kind in systems) return systems[kind][isMetric ? 0 : 1];
  return undefined;
};

exports.representKindAsUnit = representKindAsUnit;

var representUnit = function representUnit(values, fromUnit, units) {
  var toUnit = representKindAsUnit((0, _jsQuantities["default"])(1, fromUnit).kind, units);
  if (toUnit === undefined) return {
    values: values,
    unit: fromUnit
  };

  var converter = _jsQuantities["default"].swiftConverter(fromUnit, toUnit);

  return {
    value: converter(values),
    unit: toUnit
  };
};

exports.representUnit = representUnit;

var representFromBaseUnit = function representFromBaseUnit(values, kind, units) {
  return representUnit(values, (0, _jsQuantities["default"])(1, _jsQuantities["default"].getUnits(kind)[0]).toBase().units(), units);
};

exports.representFromBaseUnit = representFromBaseUnit;

var getUnitLabel = function getUnitLabel(unit, units) {
  var kind = unitToKind(unit);

  if (kind in units.systems) {
    var def = units.systems[kind].find(function (u) {
      return u.abbv === unit;
    });
    if (def && def.label !== undefined) return def.label;
  }

  return unit;
};

exports.getUnitLabel = getUnitLabel;